posterior_mean: posterior_mean
Description
This is an internal (non-exported) function. This help
page provides additional documentation mainly intended for
developers and expert users.
Usage
posterior_mean(bhat, Vinv, U1)
Arguments
Vinv
R x R inverse covariance matrix for the likelihood
U1
R x R posterior covariance matrix, computed using posterior_cov
Value
R vector of posterior mean
Details
If bhat is N(b,V) and b is N(0,U) then b|bhat
N(mu1,U1). This function returns mu1.